@@ -27,6 +27,7 @@ from pygpsclient.globals import (
     WIDGETU2,
     MAPURL,
     MAP_UPDATE_INTERVAL,
+    MAPQTIMEOUT,
     IMG_WORLD,
     ICON_POS,
     BGCOL,
@@ -54,7 +55,7 @@ class MapviewFrame(Frame):
         """
 
         self.__app = app  # Reference to main application class
-        self.__master = self.__app.get_master()  # Reference to root class (Tk)
+        self.__master = self.__app.appmaster  # Reference to root class (Tk)
 
         Frame.__init__(self, self.__master, *args, **kwargs)
 
@@ -161,7 +162,7 @@ class MapviewFrame(Frame):
         url = self._format_url(apikey, lat, lon, hacc)
 
         try:
-            response = get(url)
+            response = get(url, timeout=MAPQTIMEOUT)
             sc = responses[response.status_code]  # get descriptive HTTP status
             response.raise_for_status()  # raise Exception on HTTP error
             if sc == "OK":
@@ -204,9 +205,22 @@ class MapviewFrame(Frame):
 
         w, h = self.width, self.height
         radius = str(hacc / 1000)  # km
+        zoom = self.__app.frm_settings.mapzoom
+        # seems to be bug in MapQuest API which causes error
+        # if scalebar displayed at maximum zoom
+        scalebar = "true" if zoom < 20 else "false"
 
         return MAPURL.format(
-            apikey, lat, lon, self.__app.frm_settings.mapzoom, radius, lat, lon, w, h
+            apikey,
+            lat,
+            lon,
+            zoom,
+            w,
+            h,
+            radius,
+            lat,
+            lon,
+            scalebar,
         )
 
     def _disp_error(self, msg):
